import os

import dotenv
import flask

from . import authentication


def create_app() -> flask.Flask:
    from . import views

    app = flask.Flask(__name__)
    app.logger.info("Setting up app")

    with app.app_context():
        app.logger.debug("Loading config file")

        dotenv.load_dotenv()

        for envvar_name in (
            "OIDC_RP_REALM_URL",
            "OIDC_RP_CLIENT_ID",
            "OIDC_RP_CLIENT_SECRET",
            "SITE_URL",
            "SECRET_KEY",
            "JWT_SECRET_KEY",
        ):
            app.config[envvar_name] = os.getenv(envvar_name)

        app.config["JWT_EXPIRES_AFTER"] = int(os.getenv("JWT_EXPIRES_AFTER"))
        app.config["ALLOWED_OIDC_GROUPS"] = os.getenv("ALLOWED_OIDC_GROUPS").split(",")

        for blueprint in (views.frontend_blueprint, views.oidc_blueprint):
            app.logger.debug("Registering blueprint: %s", blueprint)

            app.register_blueprint(blueprint)

    return app
