import functools
import typing

import authlib.jose
import flask
import werkzeug


def authentication_required(func: typing.Callable) -> typing.Callable:
    @functools.wraps(func)
    def decorator(*args, **kwargs) -> typing.Any:
        if "token" not in flask.request.cookies:
            return flask.redirect(flask.url_for("oidc.login"))

        try:
            claims = authlib.jose.jwt.decode(
                flask.request.cookies["token"],
                flask.current_app.config["JWT_SECRET_KEY"],
            )
        except authlib.jose.JoseError as exception:
            raise werkzeug.exceptions.BadRequest from exception

        try:
            claims.validate()
        except authlib.jose.JoseError as exception:
            flask.current_app.logger.info(
                "Claim validation failed for user %s: %s", claims["sub"], exception
            )

            return flask.redirect(flask.url_for("oidc.login"))

        return func(*args, **kwargs)

    return decorator
